# This Build.PL for CPAN-Test-Dummy-Perl5-EmptyProvides was generated by Dist::Zilla::Plugin::ModuleBuildTiny 0.008.
use strict;
use warnings;

use 5.008005;
use Module::Build::Tiny 0.039;
Build_PL();
